

Mouser Vendor Get Part Profiling
********************************

.. seealso:: :func:`profiling.sourcing.vendors.profile_vendor_get_part`

:download:`Raw execution profile <../../../profiling/sourcing/get_part/mouser.profile>`
:download:`SVG of execution profile <../../../profiling/sourcing/get_part/mouser.profile.svg>`

    .. rubric:: Execution Profile

    .. image:: ../../../profiling/sourcing/get_part/mouser.profile.svg

    .. rubric:: pstats Output

    .. literalinclude:: ../../../profiling/sourcing/get_part/mouser.profile.stats

